@@ -75,9 +75,9 @@ def test_convert_to_double():
     _test_convert("1.1", "double", 1.1)
     _test_convert(pd.NaT, "double", None)
     _assert_raise(pdt, "double")
-    _test_convert(FLOAT_NAN, "double", FLOAT_NAN)
-    _test_convert("nan", "double", FLOAT_NAN)
-    _test_convert("NaN", "double", FLOAT_NAN)
+    _test_convert(FLOAT_NAN, "double", None)
+    _test_convert("nan", "double", None)
+    _test_convert("NaN", "double", None)
     _test_convert(FLOAT_INF, "double", FLOAT_INF)
     _test_convert("inf", "double", FLOAT_INF)
     _test_convert("INF", "double", FLOAT_INF)
@@ -95,6 +95,8 @@ def test_convert_to_bool():
     pdt = pd.Timestamp("2020-01-01T02:03:04")
 
     _test_convert(None, "bool", None)
+    _test_convert(True, "bool", True)
+    _test_convert(False, "bool", False)
     _test_convert("true", "bool", True)
     _test_convert("True", "bool", True)
     _test_convert("false", "bool", False)
@@ -109,11 +111,11 @@ def test_convert_to_datetime():
     pdt = pd.Timestamp("2020-01-01T02:03:04")
     dt = datetime(2020, 1, 1, 2, 3, 4)
     d = date(2020, 1, 1)
-    _test_convert(None, "datetime", pd.NaT)
+    _test_convert(None, "datetime", None)
     _assert_raise("1", "datetime")
     _test_convert("2020-01-01 02:03:04", "datetime", dt)
     _test_convert("2020-01-01", "datetime", datetime(2020, 1, 1))
-    _test_convert(pd.NaT, "datetime", pd.NaT)
+    _test_convert(pd.NaT, "datetime", None)
     _test_convert(pdt, "datetime", dt)
     assert isinstance(_to_pydatetime(pdt), datetime)
     assert not isinstance(_to_pydatetime(pdt), pd.Timestamp)
@@ -126,11 +128,11 @@ def test_convert_to_date():
     pdt = pd.Timestamp("2020-01-01T02:03:04")
     dt = datetime(2020, 1, 1, 2, 3, 4)
     d = date(2020, 1, 1)
-    _test_convert(None, "date", pd.NaT)
+    _test_convert(None, "date", None)
     _assert_raise("1", "date")
     _test_convert("2020-01-01 02:03:04", "date", d)
     _test_convert("2020-01-01", "date", d)
-    _test_convert(pd.NaT, "date", pd.NaT)
+    _test_convert(pd.NaT, "date", None)
     _test_convert(pdt, "date", d)
     assert isinstance(_to_pydate(pdt), date)
     assert not isinstance(_to_pydate(pdt), pd.Timestamp)
